[][src]Struct vimwiki_server::components::ListItem

pub struct ListItem {
    pub item_type: ListItemType,
    pub suffix: ListItemSuffix,
    pub pos: usize,
    pub contents: ListItemContents,
}

Represents an item in a list

Fields

item_type: ListItemTypesuffix: ListItemSuffixpos: usizecontents: ListItemContents

Implementations

impl ListItem[src]

pub fn is_unordered(&self) -> bool[src]

Indicates whether or not this list item represents an unordered item

pub fn is_ordered(&self) -> bool[src]

Indicates whether or not this list item represents an ordered item

pub fn to_prefix(&self) -> String[src]

Allocates a new string to represent the prefix of this list item

impl ListItem[src]

pub fn new(
    item_type: ListItemType,
    suffix: ListItemSuffix,
    pos: usize,
    contents: ListItemContents
) -> ListItem
[src]