[][src]Struct vimwiki_server::Program

pub struct Program { /* fields omitted */ }

Contains the state of the program while it is running

Implementations

impl Program[src]

pub async fn run(config: Config) -> Result<(), ProgramError>[src]

Runs our program

pub async fn load_and_watch_graphql_page<'_>(
    &'_ self,
    path: impl AsRef<Path>,
    reload: bool
) -> Option<Page>
[src]

Loads a GraphQL page with the given path and begins to watch it for changes (if not already being watched)

pub async fn graphql_pages<'_>(&'_ self) -> Vec<Page>[src]

Returns all graphql pages contained in the database

pub async fn wiki_by_index<'_>(&'_ self, index: usize) -> Option<Wiki>[src]

Returns the wiki at the given index in the database

pub async fn wiki_by_name<'_, '_>(&'_ self, name: &'_ str) -> Option<Wiki>[src]

Returns the wiki with the given name in the database