[−][src]Struct vimwiki_server::components::DefinitionList
Represents a list of terms and definitions, where a term can have multiple definitions associated with it
Implementations
impl DefinitionList[src]
pub fn get(&self, term: &str) -> Option<&TermAndDefinitions>[src]
Retrieves a term and its associated definitions
pub fn iter(&self) -> impl Iterator<Item = &TermAndDefinitions>[src]
Iterates through all term and definitions instances in list
pub fn terms(&self) -> impl Iterator<Item = &LocatedComponent<String>>[src]
Iterates through all terms in the list
pub fn defs_for_term(
&self,
term: &str
) -> Option<impl Iterator<Item = &LocatedComponent<String>>>[src]
&self,
term: &str
) -> Option<impl Iterator<Item = &LocatedComponent<String>>>
Retrieves the definitions for a term
impl DefinitionList[src]
pub fn new(
terms_and_definitions: HashSet<TermAndDefinitions, RandomState>
) -> DefinitionList[src]
terms_and_definitions: HashSet<TermAndDefinitions, RandomState>
) -> DefinitionList